OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Messaggio incorporato %s",
    "Important mail" : "Posta importante",
    "No message found yet" : "Ancora nessun messaggio trovato",
    "Set up an account" : "Configura un account",
    "Unread mail" : "Messaggio non letto",
    "Important" : "Importante",
    "Work" : "Lavoro",
    "Personal" : "Personale",
    "To Do" : "Da fare",
    "Later" : "Più tardi",
    "Mail" : "Posta",
    "You are reaching your mailbox quota limit for {account_email}" : "Stai raggiungendo il limite della tua quota della casella di posta per {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Stai utilizzando attualmente {percentage} dello spazio di archiviazione della tua casella di posta. Libera spazio eliminando le email non necessarie.",
    "Mails" : "Messaggi di posta",
    "💌 A mail app for Nextcloud" : "💌 Un'applicazione di posta per Nextcloud",
    "Your session has expired. The page will be reloaded." : "La sessione è scaduta. La pagina sarà ricaricata.",
    "Drafts are saved in:" : "Le bozze sono salvate in:",
    "Sent messages are saved in:" : "I messaggi inviati sono salvati in:",
    "Deleted messages are moved in:" : "I messaggi eliminati sono spostati in:",
    "Archived messages are moved in:" : "I messaggi archiviati sono spostati in:",
    "Junk messages are saved in:" : "I messaggi indesiderati sono salvati in:",
    "Connecting" : "Connessione in corso",
    "Reconnect Google account" : "Ricollega l'account di Google",
    "Sign in with Google" : "Accedi con Google",
    "Save" : "Salva",
    "Connect" : "Connetti",
    "Checking mail host connectivity" : "Verifica della connettività dell'host di posta",
    "Password required" : "Password richiesta",
    "Awaiting user consent" : "In attesa del consenso dell'utente.",
    "Loading account" : "Caricamento account",
    "Account updated" : "Account aggiornato",
    "IMAP server is not reachable" : "Il server IMAP non è raggiungibile",
    "SMTP server is not reachable" : "Il server SMTP non è raggiungibile",
    "IMAP username or password is wrong" : "Il nome utente o la password IMAP sono errati.",
    "SMTP username or password is wrong" : "Il nome utente o la password SMTP sono errati.",
    "IMAP connection failed" : "Connessione IMAP non riuscita",
    "SMTP connection failed" : "Connessione SMTP non riuscita",
    "Auto" : "Automatico",
    "Name" : "Nome",
    "Mail address" : "Indirizzo di posta",
    "name@example.org" : "nome@esempio.org",
    "Please enter an email of the format name@example.com" : "Inserisci un'email nel formato name@esempio.com",
    "Password" : "Password",
    "Manual" : "Manuale",
    "IMAP Settings" : "Impostazioni IMAP",
    "IMAP Host" : "Host IMAP",
    "IMAP Security" : "Sicurezza IMAP",
    "None" : "Nessuna",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Utente IMAP",
    "IMAP Password" : "Password IMAP",
    "SMTP Settings" : "Impostazioni SMTP",
    "SMTP Host" : "Host SMTP",
    "SMTP Security" : "Sicurezza SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Account settings" : "Impostazioni account",
    "Aliases" : "Alias",
    "Signature" : "Firma",
    "A signature is added to the text of new messages and replies." : "Una firma sarà aggiunta al testo dei nuovi messaggi e delle risposte.",
    "Writing mode" : "Modalità di scrittura",
    "Preferred writing mode for new messages and replies." : "Modalità di scrittura preferita per nuovi messaggi e risposte.",
    "Default folders" : "Cartelle predefinite",
    "Autoresponder" : "Risponditore automatico",
    "Filters" : "Filtri",
    "Mail server" : "Server di posta",
    "Update alias" : "Aggiorna alias",
    "Rename alias" : "Rinomina alias",
    "Show update alias form" : "Mostra modulo aggiornamento alias",
    "Delete alias" : "Elimina alias",
    "Go back" : "Indietro",
    "Change name" : "Cambia il nome",
    "Email address" : "Indirizzo email",
    "Add alias" : "Aggiungi alias",
    "Create alias" : "Crea alias",
    "Cancel" : "Annulla",
    "Activate" : "Attiva",
    "Put my text to the bottom of a reply instead of on top of it." : "Inserisci il mio testo in fondo alla risposta invece che sopra.",
    "Could not update preference" : "Impossibile aggiornare la preferenza",
    "Mail settings" : "Impostazioni Posta",
    "Accounts" : "Account",
    "Add mail account" : "Aggiungi account di posta",
    "General" : "Generale",
    "Layout" : "Disposizione",
    "List" : "Elenco",
    "Sorting" : "Ordina",
    "Newest" : "Più recente",
    "Oldest" : "Il più datato",
    "Gravatar settings" : "Impostazioni Gravatar",
    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
    "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
    "Register" : "Registra",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
    "Trusted senders" : "Mittenti affidabili",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME",
    "Mailvelope" : "Mailvelope",
    "About" : "Informazioni",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Compose new message" : "Componi nuovo messaggio",
    "Newer message" : "Messaggio più recente",
    "Older message" : "Messaggio più datato",
    "Toggle star" : "Commuta stella",
    "Toggle unread" : "Commuta non letto",
    "Archive" : "Archivio",
    "Delete" : "Elimina",
    "Search" : "Cerca",
    "Send" : "Invia",
    "Refresh" : "Aggiorna",
    "No certificate" : "Nessun certificato",
    "Certificate updated" : "Certificato aggiornato",
    "Could not update certificate" : "Impossibile aggiornare il certificato",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Valido fino al {expiryDate}",
    "Select an alias" : "Seleziona un alias",
    "Update Certificate" : "Aggiorna certificato",
    "Encrypt with S/MIME and send later" : "Cifra con S/MIME e invia in seguito",
    "Encrypt with S/MIME and send" : "Cifra con S/MIME e invia",
    "Encrypt with Mailvelope and send later" : "Cifra con Mailvelope e invia in seguito",
    "Encrypt with Mailvelope and send" : "Cifra con Mailvelope e invia",
    "Send later" : "Invia più tardi",
    "Message {id} could not be found" : "Il messaggio {id} non può essere trovato",
    "Keep formatting" : "Mantieni la formattazione",
    "From" : "Da",
    "Select account" : "Seleziona account",
    "To" : "A",
    "Contact or email address …" : "Contatto o indirizzo email...",
    "Cc" : "Cc",
    "Bcc" : "Ccn",
    "Subject" : "Oggetto",
    "Subject …" : "Oggetto...",
    "This message came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
    "The following recipients do not have a PGP key: {recipients}." : "I seguenti destinatari non hanno una chiave PGP: {recipients}.",
    "Write message …" : "Scrivi messaggio...",
    "Saving draft …" : "Salvataggio bozza…",
    "Draft saved" : "Bozza salvata",
    "Save draft" : "Salva bozza",
    "Discard & close draft" : "Scarta e chiudi bozza",
    "Enable formatting" : "Abilita formattazione",
    "Disable formatting" : "Disabilita la formattazione",
    "Upload attachment" : "Carica allegato",
    "Add attachment from Files" : "Aggiungi allegato da File",
    "Smart picker" : "Selettore intelligente",
    "Request a read receipt" : "Richiedi una conferma di lettura",
    "Sign message with S/MIME" : "Firma il messaggio con S/MIME",
    "Encrypt message with S/MIME" : "Cifra il messaggio con S/MIME",
    "Encrypt message with Mailvelope" : "Cifra il messaggio con Mailvelope",
    "Send now" : "Spedisci ora",
    "Tomorrow morning" : "Domattina",
    "Tomorrow afternoon" : "Domani pomeriggio",
    "Monday morning" : "Lunedi mattina",
    "Custom date and time" : "Data e ora personalizzate",
    "Enter a date" : "Digita una data",
    "Choose" : "Scegli",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece il file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento."],
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "Choose a file to share as a link" : "Scegli un file da condividere come un collegamento",
    "_{count} attachment_::_{count} attachments_" : ["{count} allegato","{count} allegati","{count} allegati"],
    "Untitled message" : "Messaggio senza titolo",
    "Expand composer" : "Espandi compositore",
    "Close composer" : "Chiudi compositore",
    "Confirm" : "Conferma",
    "Plain text" : "Testo semplice",
    "Rich text" : "Testo formattato",
    "No messages in this folder" : "Nessun messaggio in questa cartella",
    "No messages" : "Nessun messaggio",
    "Blind copy recipients only" : "Solo destinatari in copia nascosta",
    "No subject" : "Nessun oggetto",
    "Later today – {timeLocale}" : "Oggi – {timeLocale}",
    "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
    "Tomorrow – {timeLocale}" : "Domani – {timeLocale}",
    "Set reminder for tomorrow" : "Imposta promemoria per domani",
    "This weekend – {timeLocale}" : "Questo fine settimana – {timeLocale}",
    "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
    "Next week – {timeLocale}" : "Prossima settimana – {timeLocale}",
    "Set reminder for next week" : "Imposta promemoria per la prossima settimana",
    "Could not delete message" : "Impossibile eliminare il messaggio",
    "Could not archive message" : "Impossibile archiviare il messaggio",
    "Encrypted message" : "Messaggio cifrato",
    "This message is unread" : "Questo messaggio è non letto",
    "Unfavorite" : "Rimuovi preferito",
    "Favorite" : "Preferito",
    "Unread" : "Da leggere",
    "Read" : "Lettura",
    "Unimportant" : "Non importanti",
    "Mark not spam" : "Marca come posta non indesiderata",
    "Mark as spam" : "Marca come posta indesiderata",
    "Edit tags" : "Modifica etichette",
    "Move thread" : "Sposta conversazione",
    "Archive thread" : "Archivia la discussione",
    "Archive message" : "Messaggio di archivio",
    "Delete thread" : "Elimina conversazione",
    "Delete message" : "Elimina messaggio",
    "More actions" : "Altre azioni",
    "Back" : "Indietro",
    "Edit as new message" : "Modifica come nuovo messaggio",
    "Create event" : "Crea evento",
    "Create task" : "Crea attività",
    "Download message" : "Scarica messaggio",
    "Load more" : "Carica altro",
    "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} come letto","Marca {number} come letti","Marca {number} come letti"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} come non letto","Marca {number} come non letti","Marca {number} come non letti"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Marca {number} come importante","Marca {number} come importante","Marca {number} come importante"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marca {number} come non importante","Marca {number} come non importante","Marca {number} come non importante"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Rimuovi dai preferiti {number}","Rimuovi dai preferiti {number}","Rimuovi dai preferiti {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Aggiungi ai preferiti {number}","Aggiungi ai preferiti {number}","Aggiungi ai preferiti {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Deseleziona {number}","Deseleziona {number}","Deseleziona {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Sposta {number} conversazione","Sposta {number} conversazioni","Sposta {number} conversazioni"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} come allegato","Inoltra {number} come allegati","Inoltra {number} come allegati"],
    "Report this bug" : "Segnala questo bug",
    "Event created" : "Evento creato",
    "Could not create event" : "Impossibile creare l'evento",
    "All day" : "Tutto il giorno",
    "Select calendar" : "Seleziona calendario",
    "Description" : "Descrizione",
    "Create" : "Crea",
    "This event was updated" : "Questo evento è stato aggiornato",
    "{attendeeName} accepted your invitation" : "{attendeeName} ha accettato il tuo invito",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} ha accettato provvisoriamente il tuo invito",
    "{attendeeName} declined your invitation" : "{attendeeName} ha rifiutato il tuo invito",
    "{attendeeName} reacted to your invitation" : "{attendeeName} ha reagito al tuo invito",
    "Failed to save your participation status" : "Impossibile salvare lo stato della tua partecipazione",
    "You accepted this invitation" : "Hai accettato questo invito",
    "You tentatively accepted this invitation" : "Hai accettato provvisoriamente questo invito",
    "You declined this invitation" : "Hai rifiutato questo invito",
    "You already reacted to this invitation" : "Hai già reagito a questo invito",
    "You have been invited to an event" : "Sei stato invitato a un evento",
    "This event was cancelled" : "Questo evento è stato annullato",
    "Save to" : "Salva in",
    "Select" : "Seleziona",
    "Comment" : "Commento",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Tentatively accept" : "Accetta provvisoriamente",
    "More options" : "Altre opzioni",
    "individual" : "individuale",
    "domain" : "dominio",
    "Remove" : "Rimuovi",
    "Itinerary for {type} is not supported yet" : "L'itinerario per {type} non è ancora supportato",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Non ti è consentito spostare questo messaggio nella cartella degli archivi e/o eliminare questo messaggio dalla cartella corrente.",
    "Loading messages …" : "Caricamento messaggi...",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "No more submailboxes in here" : "Qui non ci sono altre sotto-caselle di posta",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "I messaggi saranno automaticamente contrassegnati come importanti in base ai messaggi con cui hai interagito o contrassegnati come importanti. All'inizio potresti dover cambiare manualmente l'importanza per addestrare il sistema, ma migliorerà nel tempo.",
    "Important info" : "Informazione importante",
    "Other" : "Altro",
    "Could not send mdn" : "Impossibile inviare mdn",
    "The sender of this message has asked to be notified when you read this message." : "Il mittente di questo messaggio ha chiesto di essere avvisato quando leggi questo messaggio.",
    "Notify the sender" : "Notifica al mittente",
    "You sent a read confirmation to the sender of this message." : "Hai inviato una conferma di lettura al mittente di questo messaggio.",
    "Forward" : "Inoltra",
    "Move message" : "Sposta messaggio",
    "Translate" : "Traduci",
    "View source" : "Visualizza sorgente",
    "Download thread data for debugging" : "Scarica i dati del conversazione per il debug",
    "Message body" : "Corpo del messaggio",
    "Unnamed" : "Senza nome",
    "Embedded message" : "Messaggio incorporato",
    "calendar imported" : "calendario importato",
    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
    "Import into calendar" : "Importa nel calendario",
    "Download attachment" : "Scarica allegato",
    "Save to Files" : "Salva in File",
    "Choose a folder to store the attachments in" : "Scegli una cartella in cui salvare gli allegati",
    "Save all to Files" : "Salva tutto in File",
    "Download Zip" : "Scarica Zip",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Questo messaggio è cifrato con PGP. Installa Mailvelope per decifrarlo.",
    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
    "Show images" : "Mostra le immagini",
    "Show images temporarily" : "Mostra temporaneamente le immagini",
    "Always show images from {sender}" : "Mostra sempre le immagini da {sender}",
    "Always show images from {domain}" : "Mostra sempre le immagini da {domain}",
    "Message frame" : "Riquadro del messaggio",
    "Quoted text" : "Testo citato",
    "Move" : "Sposta",
    "Moving" : "Spostamento",
    "Moving thread" : "Spostamento conversazione",
    "Moving message" : "Spostamento messaggio",
    "Remove account" : "Rimuovi account",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "L'account per {email} e i dati di posta elettronica memorizzati nella cache saranno rimossi da Nextcloud, ma non dal tuo fornitore di posta elettronica.",
    "Remove {email}" : "Rimuovi {email}",
    "Show only subscribed folders" : "Mostra solo le cartelle sottoscritte",
    "Add folder" : "Aggiungi cartella",
    "Folder name" : "Nome della cartella",
    "Saving" : "Salvataggio",
    "Move up" : "Sposta su",
    "Move down" : "Sposta giù",
    "Show all subscribed folders" : "Mostra tutte le cartelle sottoscritte",
    "Show all folders" : "Mostra tutte le cartelle",
    "Collapse mailboxes" : "Contrai le caselle di posta",
    "_{total} message_::_{total} messages_" : ["{total} messaggio","{total} messaggi","{total} messaggi"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non letto di {total}","{unread} non letti di {total}","{unread} non letti di {total}"],
    "Loading …" : "Caricamento in corso...",
    "The folder and all messages in it will be deleted." : "La cartella e tutti i messaggi in essa saranno eliminati.",
    "Delete folder" : "Elimina cartella",
    "Delete folder {name}" : "Elimina cartella {name}",
    "An error occurred, unable to rename the mailbox." : "Si è verificato un errore, impossibile rinominare la casella di posta.",
    "Mark all as read" : "Marca tutti come letti",
    "Mark all messages of this folder as read" : "Marca tutti i messaggi di questa cartella come letti",
    "Add subfolder" : "Aggiungi sottocartella",
    "Rename" : "Rinomina",
    "Move folder" : "Sposta cartella",
    "Clear cache" : "Svuota cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Cancella i dati locali in cache, nel caso ci siano problemi di sincronizzazione.",
    "Subscribed" : "Sottoscritta",
    "Sync in background" : "Sincronizza in background",
    "Outbox" : "Posta in uscita",
    "New message" : "Nuovo messaggio",
    "Edit message" : "Modifica messaggio",
    "Draft" : "Bozza",
    "Reply" : "Rispondi",
    "Message saved" : "Messaggio salvato",
    "Failed to save message" : "Impossibile salvare il messaggio",
    "Failed to save draft" : "Impossibile salvare la bozza",
    "attachment" : "allegato",
    "attached" : "allegato",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Stai tentando di inviare a troppi destinatari in A e/o CC. Considera l'idea di utilizzare CCN per nascondere gli indirizzi dei destinatari.",
    "You mentioned an attachment. Did you forget to add it?" : "Hai menzionato un allegato. Hai dimenticato di aggiungerlo?",
    "Message discarded" : "Messaggio scartato",
    "Could not discard message" : "Impossibile eliminare il messaggio",
    "Error sending your message" : "Errore di invio del messaggio",
    "Retry" : "Riprova",
    "Warning sending your message" : "Avviso durante l'invio del tuo messaggio",
    "Send anyway" : "Invia comunque",
    "First day" : "Primo giorno",
    "Last day (optional)" : "Ultimo giorno (facoltativo)",
    "Message" : "Messaggio",
    "Oh Snap!" : "Accidenti!",
    "Could not open outbox" : "Impossibile aprire la posta in uscita",
    "Message could not be sent" : "Il messaggio non può essere inviato",
    "Message deleted" : "Messaggio eliminato",
    "Copied email address to clipboard" : "Indirizzo email copiato negli appunti",
    "Could not copy email address to clipboard" : "Impossibile copiare l'indirizzo email negli appunti",
    "Contacts with this address" : "Contatti con questo indirizzo",
    "Add to Contact" : "Aggiungi ai contatti",
    "New Contact" : "Nuovo contatto",
    "Copy to clipboard" : "Copia negli appunti",
    "Contact name …" : "Nome contatto …",
    "Add" : "Aggiungi",
    "Show less" : "Mostra meno",
    "Show more" : "Mostra più",
    "Clear" : "Pulisci",
    "Close" : "Chiudi",
    "Search parameters" : "Parametri di ricerca",
    "Search subject" : "Cerca nell'oggetto",
    "Body" : "Corpo",
    "Search body" : "Cerca nel corpo",
    "Date" : "Data",
    "Pick a start date" : "Scegli una data di inizio",
    "Pick an end date" : "Scegli una data di fine",
    "Select senders" : "Seleziona i mittenti",
    "Select recipients" : "Seleziona i destinatari",
    "Select CC recipients" : "Seleziona i destinatari CC",
    "Select BCC recipients" : "Seleziona i destinatari CCN",
    "Tags" : "Etichette",
    "Select tags" : "Seleziona etichette",
    "Has attachments" : "Ha allegati",
    "Last 7 days" : "Ultimi 7 giorni",
    "Sieve Port" : "Porta Sieve",
    "IMAP credentials" : "Credenziali IMAP",
    "Custom" : "Personalizzato",
    "Sieve User" : "Utente Sieve",
    "Sieve Password" : "Password Sieve",
    "Save sieve settings" : "Salva impostazione Sieve",
    "Save sieve script" : "Salva script Sieve",
    "Signature …" : "Firma...",
    "Save signature" : "Salva firma",
    "Place signature above quoted text" : "Posiziona la firma sopra il testo citato",
    "Message source" : "Sorgente del messaggio",
    "An error occurred, unable to rename the tag." : "Si è verificato un errore, impossibile rinominare l'etichetta.",
    "Edit name or color" : "Modifica nome o colore",
    "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
    "Delete tag" : "Elimina etichetta",
    "Tag already exists" : "L'etichetta esiste già",
    "An error occurred, unable to create the tag." : "Si è verificato un errore, impossibile creare l'etichetta.",
    "Add default tags" : "Aggiungi etichette predefiniti",
    "Add tag" : "Aggiungi etichetta",
    "Saving tag …" : "Salvataggio etichetta …",
    "Task created" : "Attività creata",
    "Could not create task" : "Impossibile creare l'attività",
    "Could not load your message thread" : "Impossibile caricare la tua discussione",
    "Not found" : "Non trovato",
    "Encrypted & verified " : "Cifrato e verificato",
    "Signature verified" : "Firma verificata",
    "Signature unverified " : "Firma non verificata",
    "This message was encrypted by the sender before it was sent." : "Questo messaggio è stato cifrato dal mittente prima di essere inviato.",
    "Reply all" : "Rispondi a tutti",
    "Unsubscribe" : "Rimuovi sottoscrizione",
    "Reply to sender only" : "Rispondi solo al mittente",
    "Mark as unread" : "Segna come non letto",
    "Mark as read" : "Segna come letto",
    "Go to latest message" : "Vai all'ultimo messaggio",
    "Go to newest message" : "Vai al messaggio più recente",
    "Translate from" : "Traduci da",
    "Translate to" : "Traduci in",
    "Could not remove trusted sender {sender}" : "Impossibile rimuovere il mittente fidato {sender}",
    "No senders are trusted at the moment." : "Nessun mittente è fidato al momento.",
    "Untitled event" : "Evento senza titolo",
    "(organizer)" : "(organizzatore)",
    "Import into {calendar}" : "Importa in {calendar}",
    "Event imported into {calendar}" : "Evento importato in {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Volo {flightNr} da {depAirport} a {arrAirport}",
    "Airplane" : "Aereo",
    "Reservation {id}" : "Prenotazione {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} da {depStation} a {arrStation}",
    "Train from {depStation} to {arrStation}" : "Treno da {depStation} a {arrStation}",
    "Train" : "Treno",
    "Flag" : "Bandiera",
    "Recipient" : "Destinatario",
    "Operator" : "Operatore",
    "contains" : "contiene",
    "matches" : "corrisponde",
    "Priority" : "Priorità",
    "Successfully updated config for \"{domain}\"" : "Configurazione aggiornata con successo per \"{domain}\"",
    "Error saving config" : "Errore durante il salvataggio della configurazione",
    "Saved config for \"{domain}\"" : "Configurazione salvata per \"{domain}\"",
    "Could not save provisioning setting" : "Impossibile salvare l'impostazione di approvvigionamento",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Approvvigionamento di {count} account completato con successo.","Approvvigionamento di {count} account completato con successo.","Approvvigionamento di {count} account completato con successo."],
    "There was an error when provisioning accounts." : "Si è verificato un errore durante il approvvigionamento degli account.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : " Account eliminati e approvvigionato correttamente per \"{domain}\"",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore durante l'eliminazione e il approvvigionamento degli account per \"{domain}\"",
    "Mail app" : "Applicazione di posta",
    "The mail app allows users to read mails on their IMAP accounts." : "L'applicazione di posta consente agli utenti di leggere i messaggi dei propri account IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Qui puoi trovare le impostazioni a livello di istanza. Le impostazioni specifiche dell'utente si trovano nell'applicazione stessa (angolo in basso a sinistra).",
    "Account provisioning" : "Account approvvigionato.",
    "A provisioning configuration will provision all accounts with a matching email address." : "Una configurazione predisposta preparerà tutti gli account con un indirizzo email corrispondente.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Usando il metacarattere (*) nel campo del dominio di predisposizione, si creerà una configurazione che si applica a tutti gli utenti, a patto che non dipendano da un'altra configurazione.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Il meccanismo di approvvigionamento darà la priorità alle configurazioni di dominio specifiche rispetto alla configurazione di dominio con caratteri jolly.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Se viene trovata una nuova configurazione corrispondente dopo che all'utente è già stato eseguito il approvvigionamento con un'altra configurazione, la nuova configurazione avrà la precedenza e all'utente verrà effettuato nuovamente il approvvigionamento con la configurazione.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Può esistere una sola configurazione per dominio e una sola configurazione di dominio con caratteri jolly.",
    "These settings can be used in conjunction with each other." : "Queste impostazioni possono essere utilizzate con altri.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Se desideri eseguire il approvvigionamento di un solo dominio per tutti gli utenti, utilizza il carattere jolly (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Questa impostazione ha più senso se utilizzi lo stesso back-end utente per la Nextcloud e il server di posta della tua organizzazione.",
    "Provisioning Configurations" : "Configurazione di approvvigionamento",
    "Add new config" : "Aggiungi nuova configurazione",
    "Provision all accounts" : "Predisponi tutti gli account",
    "Anti Spam Service" : "Servizio anti-spam",
    "You can set up an anti spam service email address here." : "È possibile impostare un indirizzo e-mail del servizio Anti-Spam qui.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Qualsiasi email contrassegnata come posta indesiderata verrà inviata al servizio anti-spam.",
    "Gmail integration" : "Integrazione Gmail",
    "Microsoft integration" : "Integrazione Microsoft",
    "Successfully set up anti spam email addresses" : "Impostare correttamente gli indirizzi e-mail anti-spam",
    "Error saving anti spam email addresses" : "Errore durante il salvataggio degli indirizzi email anti-spam",
    "Successfully deleted anti spam reporting email" : "Email di segnalazione anti-spam eliminata con successo",
    "Error deleting anti spam reporting email" : "Errore durante l'eliminazione dell'email di segnalazione anti-spam",
    "Anti Spam" : "Anti-spam",
    "Add the email address of your anti spam report service here." : "Aggiungi qui l'indirizzo email del tuo servizio di segnalazione anti-spam.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Quando si utilizza questa impostazione, viene inviata un'e-mail di rapporto al server di rapporto SPAM quando un utente fa clic su \"Segna come posta indesiderata\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Il messaggio originale verrà allegato come tipo \"message/rfc822\".",
    "\"Mark as Spam\" Email Address" : "\"Segna come spam\" l'indirizzo e-mail",
    "\"Mark Not Junk\" Email Address" : "\"Segna come posta indesiderata\" l'indirizzo e-mail",
    "Reset" : "Ripristina",
    "Google integration configured" : "Integrazione di Google configurata",
    "Could not configure Google integration" : "Impossibile configurare l'integrazione con Google",
    "Google integration unlinked" : "Integrazione Google scollegata",
    "Could not unlink Google integration" : "Impossibile scollegare l'integrazione Google.",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "Unlink" : "Scollega",
    "Microsoft integration configured" : "Integrazione Microsoft configurata",
    "Could not configure Microsoft integration" : "Impossibile configurare l'integrazione di Microsoft",
    "Microsoft integration unlinked" : "Integrazione Microsoft scollegata",
    "Could not unlink Microsoft integration" : "Impossibile scollegare l'integrazione Microsoft",
    "Tenant ID (optional)" : "ID tenant (facoltativo)",
    "Domain Match: {provisioningDomain}" : "Corrispondenza di dominio: {provisioningDomain}",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} su {host}:{port} (cifratura {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} su {host}:{port} (cifratura {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} su {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "Configurazione per \"{provisioningDomain}\"",
    "Provisioning domain" : "Approvvigionamento dominio",
    "Email address template" : "Modello d'indirizzo email",
    "IMAP" : "IMAP",
    "User" : "Utente",
    "Host" : "Host",
    "Port" : "Porta",
    "SMTP" : "SMTP",
    "Master password" : "Password principale",
    "Use master password" : "Usa password principale",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Abilita l'integrazione Sieve",
    "LDAP aliases integration" : "Integrazione degli alias LDAP",
    "Enable LDAP aliases integration" : "Abilita l'integrazione degli alias LDAP",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "L'integrazione degli alias LDAP legge un attributo dalla directory LDAP configurata per eseguire il approvvigionamento degli e-mail alias.",
    "LDAP attribute for aliases" : "Attributo LDAP per gli alias",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Un attributo multi valore per il approvvigionamento di e-mail alias. Per ogni valore viene creato un alias. Gli alias esistenti in Nextcloud che non si trovano nella directory LDAP vengono eliminati.",
    "Save Config" : "Salva configurazione",
    "Unprovision & Delete Config" : "Annullare il approvvigionamento ed eliminare la configurazione",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% e %EMAIL% verranno sostituiti con l'UID e l'e-mail dell'utente",
    "With the settings above, the app will create account settings in the following way:" : "Con le impostazioni precedenti, l'applicazione creerà le impostazioni dell'account nel modo seguente:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Il certificato PKCS #12 fornito deve contenere almeno un certificato ed esattamente una chiave privata.",
    "Failed to import the certificate. Please check the password." : "Impossibile importare il certificato. Controlla la password.",
    "Certificate imported successfully" : "Certificato importato correttamente",
    "Failed to import the certificate" : "Importare del certificato non riuscita",
    "S/MIME certificates" : "Certificati S/MIME",
    "Certificate name" : "Nome del certificato",
    "E-mail address" : "Indirizzo di posta",
    "Valid until" : "Valido fino al",
    "Delete certificate" : "Elimina certificato",
    "No certificate imported yet" : "Ancora nessun certificato importato",
    "Import certificate" : "Importa certificato",
    "Import S/MIME certificate" : "Importa certificato S/MIME",
    "PKCS #12 Certificate" : "Certificato PKCS #12",
    "PEM Certificate" : "Certificato PEM",
    "Certificate" : "Certificato",
    "Private key (optional)" : "Chiave privata (facoltativa)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La chiave privata è necessaria solo se si intende inviare email firmate e cifrate utilizzando questo certificato.",
    "Submit" : "Invia",
    "Account connected" : "Account connesso",
    "You can close this window" : "Puoi chiudere questa finestra",
    "Connect your mail account" : "Connetti il tuo account di posta",
    "To add a mail account, please contact your administrator." : "Per aggiungere un account di posta, contatta il tuo amministratore.",
    "All" : "Tutti",
    "Drafts" : "Bozze",
    "Favorites" : "Preferiti",
    "Priority inbox" : "Posta in arrivo prioritaria",
    "All inboxes" : "Tutte le cartelle di posta in arrivo",
    "Inbox" : "Posta in arrivo",
    "Junk" : "Posta indesiderata",
    "Sent" : "Posta inviata",
    "Trash" : "Cestino",
    "Connect OAUTH2 account" : "Connetti account OAUTH2",
    "Error while sharing file" : "Errore durante la condivisione del file",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}","%n nuovi messaggi \nda {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "C'è già un messaggio in corso. Tutte le modifiche non salvate andranno perse se continui!",
    "Discard changes" : "Scarta le modifiche",
    "Discard unsaved changes" : "Scartare le modifiche non salvate",
    "Keep editing message" : "Continua a modificare il messaggio",
    "Attachments were not copied. Please add them manually." : "Gli allegati non sono stati copiati. Aggiungili manualmente.",
    "Message sent" : "Messaggio inviato",
    "Could not send message" : "Impossibile inviare il messaggio",
    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
    "Could not load your message" : "Impossibile caricare il tuo messaggio",
    "Could not load the desired message" : "Impossibile caricare messaggio desiderato",
    "Could not load the message" : "Impossibile caricare il messaggio",
    "Error loading message" : "Errore durante il caricamento del messaggio",
    "Forwarding to %s" : "Inoltro a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
    "Redirect" : "Redirigi",
    "The link leads to %s" : "Il collegamento conduce a %s",
    "Continue to %s" : "Continua su %s",
    "No messages in this mailbox" : "Nessun messaggio in questa casella di posta",
    "No trash mailbox configured" : "Nessuna casella del cestino configurata",
    "Draft: " : "Bozza:",
    "To archive a message please configure an archive mailbox in account settings" : "Per archiviare un messaggio, configura una casella di posta archivio nelle impostazioni dell'account.",
    "Could not open mailbox" : "Impossibile aprire la casella di posta",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indicizzazione dei tuoi messaggi. Può richiedere più tempo per le caselle di posta più grandi.",
    "Choose target mailbox" : "Scegli la casella di posta di destinazione",
    "Show only subscribed mailboxes" : "Mostra solo le caselle di posta sottoscritte",
    "Add mailbox" : "Aggiungi casella di posta",
    "Show all subscribed mailboxes" : "Mostra tutte le caselle di posta sottoscritte",
    "Show all mailboxes" : "Mostra tutte le caselle di posta",
    "The mailbox and all messages in it will be deleted." : "La casella postale e tutti i messaggi in essa saranno eliminati.",
    "Delete mailbox" : "Elimina casella di posta",
    "Delete mailbox {name}" : "Elimina la casella di posta {name}",
    "Mark all messages of this mailbox as read" : "Marca tutti i messaggi di questa casella di posta come letti",
    "Add submailbox" : "Aggiungi sotto-casella di posta",
    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
    "Search in mailbox" : "Cerca nella casella di posta",
    "Actions" : "Azioni"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
